UpdateStatement

Struct UpdateStatement 

pub struct UpdateStatement<T: QuerySource, U, V = SetNotCalled, Ret = NoReturningClause> { /* private fields */ }
Represents a complete UPDATE statement.

See update for usage examples, or the update guide for a more exhaustive set of examples.

Implementations

Source

impl<T: QuerySource, U> UpdateStatement<T, U, SetNotCalled>

pub fn set<V>(self, values: V) -> Set<Self, V>
where T: Table, V: AsChangeset<Target = T>, UpdateStatement<T, U, V::Changeset>: AsQuery,

Provides the SET clause of the UPDATE statement.

See update for usage examples, or the update guide for a more exhaustive set of examples.

Source

impl<T: QuerySource, U, V, Ret> UpdateStatement<T, U, V, Ret>

pub fn filter<Predicate>(self, predicate: Predicate) -> Filter<Self, Predicate>
where Self: FilterDsl<Predicate>,

Adds the given predicate to the WHERE clause of the statement being constructed.

If there is already a WHERE clause, the predicate will be appended with AND. There is no difference in behavior between update(table.filter(x)) and update(table).filter(x).

Example
let updated_rows = diesel::update(users)
    .set(name.eq("Jim"))
    .filter(name.eq("Sean"))
    .execute(connection);
assert_eq!(Ok(1), updated_rows);

let expected_names = vec!["Jim".to_string(), "Tess".to_string()];
let names = users.select(name).order(id).load(connection);

assert_eq!(Ok(expected_names), names);
pub fn into_boxed<'a, DB>(self) -> IntoBoxed<'a, Self, DB>
where DB: Backend, Self: BoxedDsl<'a, DB>,

Boxes the WHERE clause of this update statement.

This is useful for cases where you want to conditionally modify a query, but need the type to remain the same. The backend must be specified as part of this. It is not possible to box a query and have it be useable on multiple backends.

A boxed query will incur a minor performance penalty, as the query builder can no longer be inlined by the compiler. For most applications this cost will be minimal.

Example
let mut query = diesel::update(users).set(name.eq("Jerk")).into_boxed();

if !params["tess_has_been_a_jerk"] {
    query = query.filter(name.ne("Tess"));
}

let updated_rows = query.execute(connection)?;
assert_eq!(1, updated_rows);

let expected_names = vec!["Jerk", "Tess"];
let names = users.select(name).order(id).load::<String>(connection)?;

assert_eq!(expected_names, names);
pub fn into_boxed_clone<'a, DB>(self) -> IntoBoxedClone<'a, Self, DB>
where DB: Backend, Self: BoxedCloneDsl<'a, DB>,

Wraps the WHERE clause of this update statement in an Arc.

This is useful for cases where you want to clone and conditionally modify a query, but need the type to remain the same. The backend must be specified as part of this. It is not possible to box a query and have it be useable on multiple backends.

A cloneable boxed query will incur a slightly greater performance penalty than a standard boxed query. In both cases, the query builder can no longer be inlined by the compiler. For most applications this cost will be minimal.

Example
let query = diesel::update(users).set(name.eq("Jerk")).into_boxed_clone();
let mut query = query.clone();

if !params["tess_has_been_a_jerk"] {
    query = query.filter(name.ne("Tess"));
}

let updated_rows = query.execute(connection)?;
assert_eq!(1, updated_rows);

let expected_names = vec!["Jerk", "Tess"];
let names = users.select(name).order(id).load::<String>(connection)?;

assert_eq!(expected_names, names);
Source

impl<T: QuerySource, U, V> UpdateStatement<T, U, V, NoReturningClause>

pub fn returning<E>( self, returns: E, ) -> UpdateStatement<T, U, V, ReturningClause<E>>
where T: Table, UpdateStatement<T, U, V, ReturningClause<E>>: Query,

Specify what expression is returned after execution of the update.

On MariaDB, rows that match the filter but whose values do not change are left out of the result, so get_result returns NotFound where execute reports one updated row (MDEV-41113).

Examples
Updating a single record:
let updated_name = diesel::update(users.filter(id.eq(1)))
    .set(name.eq("Dean"))
    .returning(name)
    .get_result(connection);
assert_eq!(Ok("Dean".to_string()), updated_name);
Returning the pre-update value (PostgreSQL 18+):

RETURNING old.col — exposed via diesel::pg::returning::old() — returns the value of the column before the update was applied. This requires PostgreSQL 18 or newer.

let was_and_now = diesel::update(users.filter(id.eq(1)))
    .set(name.eq("Dean"))
    .returning((old(name), name))
    .get_result::<(String, String)>(connection);
assert_eq!(Ok(("Sean".to_string(), "Dean".to_string())), was_and_now);