SelectQuery

Trait SelectQuery 

pub trait SelectQuery {
    type SqlType;
}
Indicates that a type is a SELECT statement.

This trait differs from Query in two ways:

  • It is implemented only for select statements, rather than all queries which return a value.
  • It has looser constraints. A type implementing SelectQuery is known to be potentially valid if used as a subselect, but it is not necessarily able to be executed.

Required Associated Types

type SqlType

The SQL type of the SELECT clause

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, S, D, W, O, LOf, G, H, LC> SelectQuery for SelectStatement<F, S, D, W, O, LOf, G, H, LC>
where S: SelectClauseExpression<F>, O: ValidOrderingForDistinct<D>,

Source

impl<ST, QS, DB, GB> SelectQuery for BoxedSelectStatement<'_, ST, QS, DB, GB>
where DB: Backend,

Source

type SqlType = ST