pub trait IntoConflictValueClause: Sealed { }Expand description
Represents a type that can be converted into a value clause for an
ON CONFLICT statement.
This trait is sealed and cannot be implemented for types outside of Diesel, and may be used to constrain generic parameters.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".