IntoConflictValueClause

Trait IntoConflictValueClause 

pub trait IntoConflictValueClause: Sealed { }
Represents a type that can be converted into a value clause for an ON CONFLICT statement.

This trait is sealed and cannot be implemented for types outside of Diesel, and may be used to constrain generic parameters.

Implementors

Source

impl<Inner, Tab> IntoConflictValueClause for ValuesClause<Inner, Tab>

Source

impl<V, Tab, QId, const STATIC_QUERY_ID: bool> IntoConflictValueClause for BatchInsert<V, Tab, QId, STATIC_QUERY_ID>