pub trait OnConflictTarget<Table>: Sealed { }
Represents the target of an ON CONFLICT clause.
ON CONFLICT
This trait is sealed and cannot be implemented for types outside of Diesel, and may be used to constrain generic parameters.