pub trait Query {
type SqlType;
}Expand description
A complete SQL query with a return type.
This can be a select statement, or a command such as update or insert
with a RETURNING clause. Unlike Expression, types implementing this
trait are guaranteed to be executable on their own.
A type which doesn’t implement this trait may still represent a complete SQL
query. For example, an INSERT statement without a RETURNING clause will
not implement this trait, but can still be executed.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".